@@ -22,7 +22,15 @@ def kill(
 		log_level = -1
 	_sudo_ = Formats.Boolean(sudo).convert(true="sudo ", false="")
 	output = utils.__execute_script__(f"{_sudo_}kill {pid}")
-	if "terminated" in output:
+	if output in ["terminated",""]:
+		if output in [""]:
+			response = processes(includes=pid)
+			if not response.success: response
+			try: 
+				response.processes[pid]
+				if loader: loader_.stop(success=False)
+				return r3sponse.error_response(f"Failed to stop process {pid}.", log_level=log_level)
+			except KeyError: a=1
 		if loader: loader_.stop()
 		return r3sponse.success_response(f"Successfully killed process {pid}.")
 	else:
